# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class PatchedrpmRpmRemote(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'url': 'str',
        'ca_cert': 'str',
        'client_cert': 'str',
        'client_key': 'str',
        'tls_validation': 'bool',
        'proxy_url': 'str',
        'proxy_username': 'str',
        'proxy_password': 'str',
        'username': 'str',
        'password': 'str',
        'pulp_labels': 'object',
        'download_concurrency': 'int',
        'max_retries': 'int',
        'policy': 'PolicyEnum',
        'total_timeout': 'float',
        'connect_timeout': 'float',
        'sock_connect_timeout': 'float',
        'sock_read_timeout': 'float',
        'headers': 'list[object]',
        'rate_limit': 'int',
        'sles_auth_token': 'str'
    }

    attribute_map = {
        'name': 'name',
        'url': 'url',
        'ca_cert': 'ca_cert',
        'client_cert': 'client_cert',
        'client_key': 'client_key',
        'tls_validation': 'tls_validation',
        'proxy_url': 'proxy_url',
        'proxy_username': 'proxy_username',
        'proxy_password': 'proxy_password',
        'username': 'username',
        'password': 'password',
        'pulp_labels': 'pulp_labels',
        'download_concurrency': 'download_concurrency',
        'max_retries': 'max_retries',
        'policy': 'policy',
        'total_timeout': 'total_timeout',
        'connect_timeout': 'connect_timeout',
        'sock_connect_timeout': 'sock_connect_timeout',
        'sock_read_timeout': 'sock_read_timeout',
        'headers': 'headers',
        'rate_limit': 'rate_limit',
        'sles_auth_token': 'sles_auth_token'
    }

    def __init__(self, name=None, url=None, ca_cert=None, client_cert=None, client_key=None, tls_validation=None, proxy_url=None, proxy_username=None, proxy_password=None, username=None, password=None, pulp_labels=None, download_concurrency=None, max_retries=None, policy=None, total_timeout=None, connect_timeout=None, sock_connect_timeout=None, sock_read_timeout=None, headers=None, rate_limit=None, sles_auth_token=None, local_vars_configuration=None):  # noqa: E501
        """PatchedrpmRpmRemote - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._url = None
        self._ca_cert = None
        self._client_cert = None
        self._client_key = None
        self._tls_validation = None
        self._proxy_url = None
        self._proxy_username = None
        self._proxy_password = None
        self._username = None
        self._password = None
        self._pulp_labels = None
        self._download_concurrency = None
        self._max_retries = None
        self._policy = None
        self._total_timeout = None
        self._connect_timeout = None
        self._sock_connect_timeout = None
        self._sock_read_timeout = None
        self._headers = None
        self._rate_limit = None
        self._sles_auth_token = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if url is not None:
            self.url = url
        self.ca_cert = ca_cert
        self.client_cert = client_cert
        self.client_key = client_key
        if tls_validation is not None:
            self.tls_validation = tls_validation
        self.proxy_url = proxy_url
        self.proxy_username = proxy_username
        self.proxy_password = proxy_password
        self.username = username
        self.password = password
        if pulp_labels is not None:
            self.pulp_labels = pulp_labels
        self.download_concurrency = download_concurrency
        self.max_retries = max_retries
        if policy is not None:
            self.policy = policy
        self.total_timeout = total_timeout
        self.connect_timeout = connect_timeout
        self.sock_connect_timeout = sock_connect_timeout
        self.sock_read_timeout = sock_read_timeout
        if headers is not None:
            self.headers = headers
        self.rate_limit = rate_limit
        self.sles_auth_token = sles_auth_token

    @property
    def name(self):
        """Gets the name of this PatchedrpmRpmRemote.  # noqa: E501

        A unique name for this remote.  # noqa: E501

        :return: The name of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PatchedrpmRpmRemote.

        A unique name for this remote.  # noqa: E501

        :param name: The name of this PatchedrpmRpmRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def url(self):
        """Gets the url of this PatchedrpmRpmRemote.  # noqa: E501

        The URL of an external content source.  # noqa: E501

        :return: The url of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this PatchedrpmRpmRemote.

        The URL of an external content source.  # noqa: E501

        :param url: The url of this PatchedrpmRpmRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                url is not None and len(url) < 1):
            raise ValueError("Invalid value for `url`, length must be greater than or equal to `1`")  # noqa: E501

        self._url = url

    @property
    def ca_cert(self):
        """Gets the ca_cert of this PatchedrpmRpmRemote.  # noqa: E501

        A PEM encoded CA certificate used to validate the server certificate presented by the remote server.  # noqa: E501

        :return: The ca_cert of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: str
        """
        return self._ca_cert

    @ca_cert.setter
    def ca_cert(self, ca_cert):
        """Sets the ca_cert of this PatchedrpmRpmRemote.

        A PEM encoded CA certificate used to validate the server certificate presented by the remote server.  # noqa: E501

        :param ca_cert: The ca_cert of this PatchedrpmRpmRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                ca_cert is not None and len(ca_cert) < 1):
            raise ValueError("Invalid value for `ca_cert`, length must be greater than or equal to `1`")  # noqa: E501

        self._ca_cert = ca_cert

    @property
    def client_cert(self):
        """Gets the client_cert of this PatchedrpmRpmRemote.  # noqa: E501

        A PEM encoded client certificate used for authentication.  # noqa: E501

        :return: The client_cert of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: str
        """
        return self._client_cert

    @client_cert.setter
    def client_cert(self, client_cert):
        """Sets the client_cert of this PatchedrpmRpmRemote.

        A PEM encoded client certificate used for authentication.  # noqa: E501

        :param client_cert: The client_cert of this PatchedrpmRpmRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                client_cert is not None and len(client_cert) < 1):
            raise ValueError("Invalid value for `client_cert`, length must be greater than or equal to `1`")  # noqa: E501

        self._client_cert = client_cert

    @property
    def client_key(self):
        """Gets the client_key of this PatchedrpmRpmRemote.  # noqa: E501

        A PEM encoded private key used for authentication.  # noqa: E501

        :return: The client_key of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: str
        """
        return self._client_key

    @client_key.setter
    def client_key(self, client_key):
        """Sets the client_key of this PatchedrpmRpmRemote.

        A PEM encoded private key used for authentication.  # noqa: E501

        :param client_key: The client_key of this PatchedrpmRpmRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                client_key is not None and len(client_key) < 1):
            raise ValueError("Invalid value for `client_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._client_key = client_key

    @property
    def tls_validation(self):
        """Gets the tls_validation of this PatchedrpmRpmRemote.  # noqa: E501

        If True, TLS peer validation must be performed.  # noqa: E501

        :return: The tls_validation of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: bool
        """
        return self._tls_validation

    @tls_validation.setter
    def tls_validation(self, tls_validation):
        """Sets the tls_validation of this PatchedrpmRpmRemote.

        If True, TLS peer validation must be performed.  # noqa: E501

        :param tls_validation: The tls_validation of this PatchedrpmRpmRemote.  # noqa: E501
        :type: bool
        """

        self._tls_validation = tls_validation

    @property
    def proxy_url(self):
        """Gets the proxy_url of this PatchedrpmRpmRemote.  # noqa: E501

        The proxy URL. Format: scheme://host:port  # noqa: E501

        :return: The proxy_url of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: str
        """
        return self._proxy_url

    @proxy_url.setter
    def proxy_url(self, proxy_url):
        """Sets the proxy_url of this PatchedrpmRpmRemote.

        The proxy URL. Format: scheme://host:port  # noqa: E501

        :param proxy_url: The proxy_url of this PatchedrpmRpmRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                proxy_url is not None and len(proxy_url) < 1):
            raise ValueError("Invalid value for `proxy_url`, length must be greater than or equal to `1`")  # noqa: E501

        self._proxy_url = proxy_url

    @property
    def proxy_username(self):
        """Gets the proxy_username of this PatchedrpmRpmRemote.  # noqa: E501

        The username to authenticte to the proxy.  # noqa: E501

        :return: The proxy_username of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: str
        """
        return self._proxy_username

    @proxy_username.setter
    def proxy_username(self, proxy_username):
        """Sets the proxy_username of this PatchedrpmRpmRemote.

        The username to authenticte to the proxy.  # noqa: E501

        :param proxy_username: The proxy_username of this PatchedrpmRpmRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                proxy_username is not None and len(proxy_username) < 1):
            raise ValueError("Invalid value for `proxy_username`, length must be greater than or equal to `1`")  # noqa: E501

        self._proxy_username = proxy_username

    @property
    def proxy_password(self):
        """Gets the proxy_password of this PatchedrpmRpmRemote.  # noqa: E501

        The password to authenticate to the proxy. Extra leading and trailing whitespace characters are not trimmed.  # noqa: E501

        :return: The proxy_password of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: str
        """
        return self._proxy_password

    @proxy_password.setter
    def proxy_password(self, proxy_password):
        """Sets the proxy_password of this PatchedrpmRpmRemote.

        The password to authenticate to the proxy. Extra leading and trailing whitespace characters are not trimmed.  # noqa: E501

        :param proxy_password: The proxy_password of this PatchedrpmRpmRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                proxy_password is not None and len(proxy_password) < 1):
            raise ValueError("Invalid value for `proxy_password`, length must be greater than or equal to `1`")  # noqa: E501

        self._proxy_password = proxy_password

    @property
    def username(self):
        """Gets the username of this PatchedrpmRpmRemote.  # noqa: E501

        The username to be used for authentication when syncing.  # noqa: E501

        :return: The username of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this PatchedrpmRpmRemote.

        The username to be used for authentication when syncing.  # noqa: E501

        :param username: The username of this PatchedrpmRpmRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                username is not None and len(username) < 1):
            raise ValueError("Invalid value for `username`, length must be greater than or equal to `1`")  # noqa: E501

        self._username = username

    @property
    def password(self):
        """Gets the password of this PatchedrpmRpmRemote.  # noqa: E501

        The password to be used for authentication when syncing. Extra leading and trailing whitespace characters are not trimmed.  # noqa: E501

        :return: The password of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this PatchedrpmRpmRemote.

        The password to be used for authentication when syncing. Extra leading and trailing whitespace characters are not trimmed.  # noqa: E501

        :param password: The password of this PatchedrpmRpmRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                password is not None and len(password) < 1):
            raise ValueError("Invalid value for `password`, length must be greater than or equal to `1`")  # noqa: E501

        self._password = password

    @property
    def pulp_labels(self):
        """Gets the pulp_labels of this PatchedrpmRpmRemote.  # noqa: E501


        :return: The pulp_labels of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: object
        """
        return self._pulp_labels

    @pulp_labels.setter
    def pulp_labels(self, pulp_labels):
        """Sets the pulp_labels of this PatchedrpmRpmRemote.


        :param pulp_labels: The pulp_labels of this PatchedrpmRpmRemote.  # noqa: E501
        :type: object
        """

        self._pulp_labels = pulp_labels

    @property
    def download_concurrency(self):
        """Gets the download_concurrency of this PatchedrpmRpmRemote.  # noqa: E501

        Total number of simultaneous connections. If not set then the default value will be used.  # noqa: E501

        :return: The download_concurrency of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: int
        """
        return self._download_concurrency

    @download_concurrency.setter
    def download_concurrency(self, download_concurrency):
        """Sets the download_concurrency of this PatchedrpmRpmRemote.

        Total number of simultaneous connections. If not set then the default value will be used.  # noqa: E501

        :param download_concurrency: The download_concurrency of this PatchedrpmRpmRemote.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                download_concurrency is not None and download_concurrency < 1):  # noqa: E501
            raise ValueError("Invalid value for `download_concurrency`, must be a value greater than or equal to `1`")  # noqa: E501

        self._download_concurrency = download_concurrency

    @property
    def max_retries(self):
        """Gets the max_retries of this PatchedrpmRpmRemote.  # noqa: E501

        Maximum number of retry attempts after a download failure. If not set then the default value (3) will be used.  # noqa: E501

        :return: The max_retries of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: int
        """
        return self._max_retries

    @max_retries.setter
    def max_retries(self, max_retries):
        """Sets the max_retries of this PatchedrpmRpmRemote.

        Maximum number of retry attempts after a download failure. If not set then the default value (3) will be used.  # noqa: E501

        :param max_retries: The max_retries of this PatchedrpmRpmRemote.  # noqa: E501
        :type: int
        """

        self._max_retries = max_retries

    @property
    def policy(self):
        """Gets the policy of this PatchedrpmRpmRemote.  # noqa: E501

        The policy to use when downloading content. The possible values include: 'immediate', 'on_demand', and 'streamed'. 'immediate' is the default.  # noqa: E501

        :return: The policy of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: PolicyEnum
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this PatchedrpmRpmRemote.

        The policy to use when downloading content. The possible values include: 'immediate', 'on_demand', and 'streamed'. 'immediate' is the default.  # noqa: E501

        :param policy: The policy of this PatchedrpmRpmRemote.  # noqa: E501
        :type: PolicyEnum
        """

        self._policy = policy

    @property
    def total_timeout(self):
        """Gets the total_timeout of this PatchedrpmRpmRemote.  # noqa: E501

        aiohttp.ClientTimeout.total (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :return: The total_timeout of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: float
        """
        return self._total_timeout

    @total_timeout.setter
    def total_timeout(self, total_timeout):
        """Sets the total_timeout of this PatchedrpmRpmRemote.

        aiohttp.ClientTimeout.total (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :param total_timeout: The total_timeout of this PatchedrpmRpmRemote.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                total_timeout is not None and total_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `total_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._total_timeout = total_timeout

    @property
    def connect_timeout(self):
        """Gets the connect_timeout of this PatchedrpmRpmRemote.  # noqa: E501

        aiohttp.ClientTimeout.connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :return: The connect_timeout of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: float
        """
        return self._connect_timeout

    @connect_timeout.setter
    def connect_timeout(self, connect_timeout):
        """Sets the connect_timeout of this PatchedrpmRpmRemote.

        aiohttp.ClientTimeout.connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :param connect_timeout: The connect_timeout of this PatchedrpmRpmRemote.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                connect_timeout is not None and connect_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `connect_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._connect_timeout = connect_timeout

    @property
    def sock_connect_timeout(self):
        """Gets the sock_connect_timeout of this PatchedrpmRpmRemote.  # noqa: E501

        aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :return: The sock_connect_timeout of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: float
        """
        return self._sock_connect_timeout

    @sock_connect_timeout.setter
    def sock_connect_timeout(self, sock_connect_timeout):
        """Sets the sock_connect_timeout of this PatchedrpmRpmRemote.

        aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :param sock_connect_timeout: The sock_connect_timeout of this PatchedrpmRpmRemote.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                sock_connect_timeout is not None and sock_connect_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `sock_connect_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._sock_connect_timeout = sock_connect_timeout

    @property
    def sock_read_timeout(self):
        """Gets the sock_read_timeout of this PatchedrpmRpmRemote.  # noqa: E501

        aiohttp.ClientTimeout.sock_read (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :return: The sock_read_timeout of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: float
        """
        return self._sock_read_timeout

    @sock_read_timeout.setter
    def sock_read_timeout(self, sock_read_timeout):
        """Sets the sock_read_timeout of this PatchedrpmRpmRemote.

        aiohttp.ClientTimeout.sock_read (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.  # noqa: E501

        :param sock_read_timeout: The sock_read_timeout of this PatchedrpmRpmRemote.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                sock_read_timeout is not None and sock_read_timeout < 0.0):  # noqa: E501
            raise ValueError("Invalid value for `sock_read_timeout`, must be a value greater than or equal to `0.0`")  # noqa: E501

        self._sock_read_timeout = sock_read_timeout

    @property
    def headers(self):
        """Gets the headers of this PatchedrpmRpmRemote.  # noqa: E501

        Headers for aiohttp.Clientsession  # noqa: E501

        :return: The headers of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: list[object]
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this PatchedrpmRpmRemote.

        Headers for aiohttp.Clientsession  # noqa: E501

        :param headers: The headers of this PatchedrpmRpmRemote.  # noqa: E501
        :type: list[object]
        """

        self._headers = headers

    @property
    def rate_limit(self):
        """Gets the rate_limit of this PatchedrpmRpmRemote.  # noqa: E501

        Limits requests per second for each concurrent downloader  # noqa: E501

        :return: The rate_limit of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: int
        """
        return self._rate_limit

    @rate_limit.setter
    def rate_limit(self, rate_limit):
        """Sets the rate_limit of this PatchedrpmRpmRemote.

        Limits requests per second for each concurrent downloader  # noqa: E501

        :param rate_limit: The rate_limit of this PatchedrpmRpmRemote.  # noqa: E501
        :type: int
        """

        self._rate_limit = rate_limit

    @property
    def sles_auth_token(self):
        """Gets the sles_auth_token of this PatchedrpmRpmRemote.  # noqa: E501

        Authentication token for SLES repositories.  # noqa: E501

        :return: The sles_auth_token of this PatchedrpmRpmRemote.  # noqa: E501
        :rtype: str
        """
        return self._sles_auth_token

    @sles_auth_token.setter
    def sles_auth_token(self, sles_auth_token):
        """Sets the sles_auth_token of this PatchedrpmRpmRemote.

        Authentication token for SLES repositories.  # noqa: E501

        :param sles_auth_token: The sles_auth_token of this PatchedrpmRpmRemote.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                sles_auth_token is not None and len(sles_auth_token) < 1):
            raise ValueError("Invalid value for `sles_auth_token`, length must be greater than or equal to `1`")  # noqa: E501

        self._sles_auth_token = sles_auth_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PatchedrpmRpmRemote):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PatchedrpmRpmRemote):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class RpmUpdateRecordResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'id': 'str',
        'updated_date': 'str',
        'description': 'str',
        'issued_date': 'str',
        'fromstr': 'str',
        'status': 'str',
        'title': 'str',
        'summary': 'str',
        'version': 'str',
        'type': 'str',
        'severity': 'str',
        'solution': 'str',
        'release': 'str',
        'rights': 'str',
        'pushcount': 'str',
        'pkglist': 'list[RpmUpdateCollectionResponse]',
        'references': 'list[object]',
        'reboot_suggested': 'bool'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'id': 'id',
        'updated_date': 'updated_date',
        'description': 'description',
        'issued_date': 'issued_date',
        'fromstr': 'fromstr',
        'status': 'status',
        'title': 'title',
        'summary': 'summary',
        'version': 'version',
        'type': 'type',
        'severity': 'severity',
        'solution': 'solution',
        'release': 'release',
        'rights': 'rights',
        'pushcount': 'pushcount',
        'pkglist': 'pkglist',
        'references': 'references',
        'reboot_suggested': 'reboot_suggested'
    }

    def __init__(self, pulp_href=None, pulp_created=None, id=None, updated_date=None, description=None, issued_date=None, fromstr=None, status=None, title=None, summary=None, version=None, type=None, severity=None, solution=None, release=None, rights=None, pushcount=None, pkglist=None, references=None, reboot_suggested=None, local_vars_configuration=None):  # noqa: E501
        """RpmUpdateRecordResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._id = None
        self._updated_date = None
        self._description = None
        self._issued_date = None
        self._fromstr = None
        self._status = None
        self._title = None
        self._summary = None
        self._version = None
        self._type = None
        self._severity = None
        self._solution = None
        self._release = None
        self._rights = None
        self._pushcount = None
        self._pkglist = None
        self._references = None
        self._reboot_suggested = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        if id is not None:
            self.id = id
        if updated_date is not None:
            self.updated_date = updated_date
        if description is not None:
            self.description = description
        if issued_date is not None:
            self.issued_date = issued_date
        if fromstr is not None:
            self.fromstr = fromstr
        if status is not None:
            self.status = status
        if title is not None:
            self.title = title
        if summary is not None:
            self.summary = summary
        if version is not None:
            self.version = version
        if type is not None:
            self.type = type
        if severity is not None:
            self.severity = severity
        if solution is not None:
            self.solution = solution
        if release is not None:
            self.release = release
        if rights is not None:
            self.rights = rights
        if pushcount is not None:
            self.pushcount = pushcount
        if pkglist is not None:
            self.pkglist = pkglist
        if references is not None:
            self.references = references
        if reboot_suggested is not None:
            self.reboot_suggested = reboot_suggested

    @property
    def pulp_href(self):
        """Gets the pulp_href of this RpmUpdateRecordResponse.  # noqa: E501


        :return: The pulp_href of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this RpmUpdateRecordResponse.


        :param pulp_href: The pulp_href of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this RpmUpdateRecordResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this RpmUpdateRecordResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this RpmUpdateRecordResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def id(self):
        """Gets the id of this RpmUpdateRecordResponse.  # noqa: E501

        Update id (short update name, e.g. RHEA-2013:1777)  # noqa: E501

        :return: The id of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RpmUpdateRecordResponse.

        Update id (short update name, e.g. RHEA-2013:1777)  # noqa: E501

        :param id: The id of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def updated_date(self):
        """Gets the updated_date of this RpmUpdateRecordResponse.  # noqa: E501

        Date when the update was updated (e.g. '2013-12-02 00:00:00')  # noqa: E501

        :return: The updated_date of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this RpmUpdateRecordResponse.

        Date when the update was updated (e.g. '2013-12-02 00:00:00')  # noqa: E501

        :param updated_date: The updated_date of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._updated_date = updated_date

    @property
    def description(self):
        """Gets the description of this RpmUpdateRecordResponse.  # noqa: E501

        Update description  # noqa: E501

        :return: The description of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RpmUpdateRecordResponse.

        Update description  # noqa: E501

        :param description: The description of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def issued_date(self):
        """Gets the issued_date of this RpmUpdateRecordResponse.  # noqa: E501

        Date when the update was issued (e.g. '2013-12-02 00:00:00')  # noqa: E501

        :return: The issued_date of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._issued_date

    @issued_date.setter
    def issued_date(self, issued_date):
        """Sets the issued_date of this RpmUpdateRecordResponse.

        Date when the update was issued (e.g. '2013-12-02 00:00:00')  # noqa: E501

        :param issued_date: The issued_date of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._issued_date = issued_date

    @property
    def fromstr(self):
        """Gets the fromstr of this RpmUpdateRecordResponse.  # noqa: E501

        Source of the update (e.g. security@redhat.com)  # noqa: E501

        :return: The fromstr of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._fromstr

    @fromstr.setter
    def fromstr(self, fromstr):
        """Sets the fromstr of this RpmUpdateRecordResponse.

        Source of the update (e.g. security@redhat.com)  # noqa: E501

        :param fromstr: The fromstr of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._fromstr = fromstr

    @property
    def status(self):
        """Gets the status of this RpmUpdateRecordResponse.  # noqa: E501

        Update status ('final', ...)  # noqa: E501

        :return: The status of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this RpmUpdateRecordResponse.

        Update status ('final', ...)  # noqa: E501

        :param status: The status of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def title(self):
        """Gets the title of this RpmUpdateRecordResponse.  # noqa: E501

        Update name  # noqa: E501

        :return: The title of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this RpmUpdateRecordResponse.

        Update name  # noqa: E501

        :param title: The title of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def summary(self):
        """Gets the summary of this RpmUpdateRecordResponse.  # noqa: E501

        Short summary  # noqa: E501

        :return: The summary of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this RpmUpdateRecordResponse.

        Short summary  # noqa: E501

        :param summary: The summary of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._summary = summary

    @property
    def version(self):
        """Gets the version of this RpmUpdateRecordResponse.  # noqa: E501

        Update version (probably always an integer number)  # noqa: E501

        :return: The version of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this RpmUpdateRecordResponse.

        Update version (probably always an integer number)  # noqa: E501

        :param version: The version of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def type(self):
        """Gets the type of this RpmUpdateRecordResponse.  # noqa: E501

        Update type ('enhancement', 'bugfix', ...)  # noqa: E501

        :return: The type of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RpmUpdateRecordResponse.

        Update type ('enhancement', 'bugfix', ...)  # noqa: E501

        :param type: The type of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def severity(self):
        """Gets the severity of this RpmUpdateRecordResponse.  # noqa: E501

        Severity  # noqa: E501

        :return: The severity of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this RpmUpdateRecordResponse.

        Severity  # noqa: E501

        :param severity: The severity of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._severity = severity

    @property
    def solution(self):
        """Gets the solution of this RpmUpdateRecordResponse.  # noqa: E501

        Solution  # noqa: E501

        :return: The solution of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._solution

    @solution.setter
    def solution(self, solution):
        """Sets the solution of this RpmUpdateRecordResponse.

        Solution  # noqa: E501

        :param solution: The solution of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._solution = solution

    @property
    def release(self):
        """Gets the release of this RpmUpdateRecordResponse.  # noqa: E501

        Update release  # noqa: E501

        :return: The release of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._release

    @release.setter
    def release(self, release):
        """Sets the release of this RpmUpdateRecordResponse.

        Update release  # noqa: E501

        :param release: The release of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._release = release

    @property
    def rights(self):
        """Gets the rights of this RpmUpdateRecordResponse.  # noqa: E501

        Copyrights  # noqa: E501

        :return: The rights of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._rights

    @rights.setter
    def rights(self, rights):
        """Sets the rights of this RpmUpdateRecordResponse.

        Copyrights  # noqa: E501

        :param rights: The rights of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._rights = rights

    @property
    def pushcount(self):
        """Gets the pushcount of this RpmUpdateRecordResponse.  # noqa: E501

        Push count  # noqa: E501

        :return: The pushcount of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: str
        """
        return self._pushcount

    @pushcount.setter
    def pushcount(self, pushcount):
        """Sets the pushcount of this RpmUpdateRecordResponse.

        Push count  # noqa: E501

        :param pushcount: The pushcount of this RpmUpdateRecordResponse.  # noqa: E501
        :type: str
        """

        self._pushcount = pushcount

    @property
    def pkglist(self):
        """Gets the pkglist of this RpmUpdateRecordResponse.  # noqa: E501

        List of packages  # noqa: E501

        :return: The pkglist of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: list[RpmUpdateCollectionResponse]
        """
        return self._pkglist

    @pkglist.setter
    def pkglist(self, pkglist):
        """Sets the pkglist of this RpmUpdateRecordResponse.

        List of packages  # noqa: E501

        :param pkglist: The pkglist of this RpmUpdateRecordResponse.  # noqa: E501
        :type: list[RpmUpdateCollectionResponse]
        """

        self._pkglist = pkglist

    @property
    def references(self):
        """Gets the references of this RpmUpdateRecordResponse.  # noqa: E501

        List of references  # noqa: E501

        :return: The references of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: list[object]
        """
        return self._references

    @references.setter
    def references(self, references):
        """Sets the references of this RpmUpdateRecordResponse.

        List of references  # noqa: E501

        :param references: The references of this RpmUpdateRecordResponse.  # noqa: E501
        :type: list[object]
        """

        self._references = references

    @property
    def reboot_suggested(self):
        """Gets the reboot_suggested of this RpmUpdateRecordResponse.  # noqa: E501

        Reboot suggested  # noqa: E501

        :return: The reboot_suggested of this RpmUpdateRecordResponse.  # noqa: E501
        :rtype: bool
        """
        return self._reboot_suggested

    @reboot_suggested.setter
    def reboot_suggested(self, reboot_suggested):
        """Sets the reboot_suggested of this RpmUpdateRecordResponse.

        Reboot suggested  # noqa: E501

        :param reboot_suggested: The reboot_suggested of this RpmUpdateRecordResponse.  # noqa: E501
        :type: bool
        """

        self._reboot_suggested = reboot_suggested

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RpmUpdateRecordResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RpmUpdateRecordResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class Repair(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'verify_checksums': 'bool'
    }

    attribute_map = {
        'verify_checksums': 'verify_checksums'
    }

    def __init__(self, verify_checksums=True, local_vars_configuration=None):  # noqa: E501
        """Repair - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._verify_checksums = None
        self.discriminator = None

        if verify_checksums is not None:
            self.verify_checksums = verify_checksums

    @property
    def verify_checksums(self):
        """Gets the verify_checksums of this Repair.  # noqa: E501

        Will verify that the checksum of all stored files matches what saved in the database. Otherwise only the existence of the files will be checked. Enabled by default  # noqa: E501

        :return: The verify_checksums of this Repair.  # noqa: E501
        :rtype: bool
        """
        return self._verify_checksums

    @verify_checksums.setter
    def verify_checksums(self, verify_checksums):
        """Sets the verify_checksums of this Repair.

        Will verify that the checksum of all stored files matches what saved in the database. Otherwise only the existence of the files will be checked. Enabled by default  # noqa: E501

        :param verify_checksums: The verify_checksums of this Repair.  # noqa: E501
        :type: bool
        """

        self._verify_checksums = verify_checksums

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Repair):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Repair):
            return True

        return self.to_dict() != other.to_dict()
